@@ -33,11 +33,11 @@ if [ $retval != 0 ]; then
 fi
 
 extract `(cd $TARGET/var/cache/apt/archives && \
-	for i in *.deb; do dpkg --info $i | grep ^\ Priority:.required \
+	for i in *.deb; do dpkg-deb --field $i Priority | grep ^required \
 	&& echo $i; done) | cut -d _ -f 1`
 
-if [ -e $TARGET/var/cache/apt/archives/gnumach_* ] ; then
-        extract gnumach
+if [ -e $TARGET/var/cache/apt/archives/gnumach-image-1.4-486_* ] ; then
+        extract gnumach-image-1.4-486
 fi
 
 if [ -e $TARGET/var/cache/apt/archives/libpthread-stubs0_* ] ; then
@@ -48,8 +48,8 @@ if [ -e $TARGET/var/cache/apt/archives/libbz2-1.0_* ] ; then
         extract libbz2-1.0
 fi
 
-if [ -e $TARGET/var/cache/apt/archives/libparted0debian1_* ] ; then
-        extract libparted0debian1
+if [ -e $TARGET/var/cache/apt/archives/libparted2_* ] ; then
+        extract libparted2
 fi
 
 x_feign_install dpkg
